pub struct CreativeFieldsListResponse {
pub next_page_token: Option<String>,
pub creative_fields: Option<Vec<CreativeField>>,
pub kind: Option<String>,
}Expand description
Creative Field List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list creative fields (response)
Fields
next_page_token: Option<String>Pagination token to be used for the next list operation.
creative_fields: Option<Vec<CreativeField>>Creative field collection.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#creativeFieldsListResponse”.